const Path = require('path');
const fs = require('fs');
const Process = require('child_process');

module.exports = class Environment {
   constructor() {
      this.modulePath = Path.resolve(__dirname, '../../');
      this.binPath = Path.join(this.modulePath, 'assets/bin');
      this.assetsDirPath = Path.join(this.modulePath, 'assets');
   }

   isCommandExists(command) {
      try {
         Process.execSync(`hash ${command} 2>/dev/null`, { stdio: 'inherit' });
         return true;
      } catch (error) {
         console.log(
            `warning: Executable "${command}" is not exist. Solution: "brew install ${command}" or "gem install --user-install ${command}"`,
         );
         return false;
      }
   }

   /**
    * @returns {boolean}
    */
   get isCI() {
      return this.isXcodeCI || this.isTravisCI || this.isJenkinsCI || this.isGenericCI;
   }

   get isXcodeCI() {
      return process.env.XCS != undefined;
   }

   get isJenkinsCI() {
      return process.env.JENKINS_HOME != undefined;
   }

   get isTravisCI() {
      return process.env.TRAVIS != undefined;
   }

   get isGenericCI() {
      return process.env.CI != undefined;
   }
};
