const fs = require('fs');
const Path = require('path');

module.exports = class FileSystem {
   static deleteContentsOf(path) {
      if (fs.existsSync(path) && fs.lstatSync(path).isDirectory()) {
         fs.readdirSync(path).forEach(function(entry) {
            const entryPath = Path.join(path.toString(), entry);
            if (fs.lstatSync(entryPath).isDirectory()) {
               FileSystem.rimraf(entryPath);
            } else {
               fs.unlinkSync(entryPath);
            }
         });
      }
   }

   static rmdirIfExists(path) {
      if (fs.existsSync(path)) {
         FileSystem.rimraf(path.toString());
      }
   }

   /**
    * Remove directory recursively
    * @param {string} dir_path
    * @see https://stackoverflow.com/a/42505874/3027390
    */
   static rimraf(path) {
      const myFunc = entry => {
         const entryPath = Path.join(path.toString(), entry);
         if (fs.lstatSync(entryPath).isDirectory()) {
            FileSystem.rimraf(entryPath);
         } else {
            fs.unlinkSync(entryPath);
         }
      };
      if (fs.existsSync(path)) {
         fs.readdirSync(path).forEach(myFunc);
         fs.rmdirSync(path);
      }
   }

   // See: https://stackoverflow.com/a/26038979/1418981
   static copyFolderRecursive(source, target) {
      if (!fs.lstatSync(source).isDirectory()) {
         return;
      }
      // check if folder needs to be created or integrated
      if (Path.basename(source) !== Path.basename(target)) {
         target = Path.join(target, Path.basename(source));
      }
      if (!fs.existsSync(target)) {
         fs.mkdirSync(target, { recursive: true });
      }
      // copy
      const myFunc = file => {
         const src = Path.join(source, file);
         const dest = Path.join(target, file);
         const stats = fs.lstatSync(src);
         if (stats.isSymbolicLink()) {
            const link = fs.readlinkSync(src);
            process.chdir(target);
            fs.symlinkSync(link, dest);
         } else if (stats.isDirectory()) {
            FileSystem.copyFolderRecursive(src, target);
         } else {
            fs.copyFileSync(src, dest);
         }
      };
      fs.readdirSync(source).forEach(myFunc);
   }
};
