const Environment = require('../Core/Environment');
const Path = require('path');
const Process = require('child_process');
const notify = require('../Core/Functions').notify;
const puts = require('../Core/Functions').puts;
const pbcopy = require('../Core/Functions').pbcopy;

const SafariURLFormat = {
   URL: 'URL',
   URLAndTitle: 'URLAndTitle',
   MD: 'MD',
   MDReference: 'MDReference',
};

module.exports = class Safari {
   constructor(isTechnologyPreview = false) {
      this.env = new Environment();
      this.isTechnologyPreview = isTechnologyPreview;
      const focusedApp = process.env.ALFRED_FOCUSD_APP;
      if (focusedApp) {
         this.isTechnologyPreview = focusedApp == 'com.apple.SafariTechnologyPreview';
      }
   }
   copyURL(format) {
      const json = this.getCurrentTabInfo();
      let result = undefined;
      switch (format) {
         case SafariURLFormat.URL:
            result = json.url;
            break;
         case SafariURLFormat.URLAndTitle:
            result = `${json.title}: ${json.url}`;
            break;
         case SafariURLFormat.MD:
            result = `[${json.title}](${json.url})`;
            break;
         case SafariURLFormat.MDReference:
            result = `[1]: ${json.url} \"${json.title}\"`;
            break;
      }
      if (result) {
         puts(`→ Copying link: ${result}`);
         pbcopy(result);
         notify(`Link: ${result}`);
      }
      return result;
   }

   getCurrentTabInfo() {
      const scriptFile = Path.join(this.env.assetsDirPath, 'AppleScript', 'Safari-URLInfo.js');
      const args = this.isTechnologyPreview ? '--preview' : '';
      const command = `osascript -l JavaScript ${scriptFile} ${args}`;
      const output = Process.execSync(command).toString();
      const json = JSON.parse(output);
      return json;
   }
};
