const Path = require('path');
const FileSystem = require('../Core/FileSystem');
const puts = require('../Core/Functions').puts;
const Environment = require('../Core/Environment');
const Process = require('child_process');

module.exports = class System {
   constructor() {
      const getEnvVariable = function(variable) {
         const value = process.env[variable];
         if (!value) {
            throw `Make sure that environment variable ${variable} is defined`;
         }
         return value;
      };
      this.homeDirPath = getEnvVariable('HOME');
      this.privateTmpDirPath = getEnvVariable('TMPDIR');
      this.privateCachesDirPath = Path.join(this.privateTmpDirPath, '/../C');
      this.env = new Environment();
   }

   setBrowserFirefox() {
      // See: https://github.com/kerma/defaultbrowser/issues/3
      Process.execSync('defaultbrowser firefox');
      const scriptFile = this.env.assetsDirPath + '/AppleScript/confirm-system-dialog.applescript';
      Process.execSync(`osascript "${scriptFile}"`);
   }

   setBrowserSafari() {
      Process.execSync('defaultbrowser safari');
      const scriptFile = this.env.assetsDirPath + '/AppleScript/confirm-system-dialog.applescript';
      Process.execSync(`osascript "${scriptFile}"`);
   }

   deleteCaches() {
      let dirs = [
         `${this.privateCachesDirPath}/com.apple.DeveloperTools`,
         `${this.privateCachesDirPath}/com.apple.dt.Instruments`,
         `${this.homeDirPath}/Library/Logs/scan`,
         `${this.homeDirPath}/Library/Logs/gym`,
         `${this.homeDirPath}/Library/Logs/Homebrew`,
         `${this.homeDirPath}/Library/Logs/CoreSimulator`,
         `${this.homeDirPath}/Library/Caches/Homebrew`,
         `${this.homeDirPath}/Library/Caches/Yarn`,
         `${this.homeDirPath}/Library/Caches/Google/Chrome`,
         `${this.homeDirPath}/Library/Caches/Mozilla`,
         `${this.homeDirPath}/Library/Caches/Firefox`,
         `${this.homeDirPath}/Library/Caches/SwiftLint`,
         `${this.homeDirPath}/Library/Caches/org.carthage.CarthageKit`,
         `${this.homeDirPath}/Library/Caches/com.docker.docker`,
         `${this.homeDirPath}/Library/Caches/com.apple.iTunes/WebKitCache`,
         `${this.homeDirPath}/Library/Caches/com.apple.iTunes/SubscriptionPlayCache`,
         `${this.homeDirPath}/Library/Caches/com.apple.iTunes/PlayCache`,
         `${this.homeDirPath}/Library/Caches/com.invisionlabs.CraftManager/Sparkle`,
         `${this.homeDirPath}/Library/Caches/com.operasoftware.Opera/Cache`,
         // `${this.homeDirPath}/Library/Caches/com.apple.SafariTechnologyPreview/WebKitCache`,
         // `${this.homeDirPath}/Library/Caches/com.apple.Safari/WebKitCache`,
         `${this.homeDirPath}/Library/Application Support/Dash/Temp`,
         `${this.homeDirPath}/Library/Application Support/io.wwdc.app`,
         `${this.homeDirPath}/Library/Application Support/ViberPC`,
         `${this.homeDirPath}/Library/Application Support/Skype/vladimir.gorlov/media_messaging/emo_cache_v2`,
         `${this.homeDirPath}/Library/Application Support/Slack/Cache`,
         `${this.homeDirPath}/Library/Application Support/Slack/temp`,
         `${this.homeDirPath}/Library/Application Support/Slack/logs`,
         `${this.homeDirPath}/Library/Developer/Xcode/DerivedData`,
         `${this.homeDirPath}/Library/Developer/Xcode/DocumentationCache`,
         `${this.homeDirPath}/Library/Developer/Xcode/UserData/IB Support/Simulator Devices`,
         `${this.homeDirPath}/Library/Developer/Xcode/iOS DeviceSupport`,
         `/Volumes/Storage/Applications/Developer/VSCode/code-portable-data/user-data/Cache`,
         `/Volumes/Storage/Applications/Developer/VSCode/code-portable-data/user-data/CachedData`,
         `/Volumes/Storage/Developer/Xcode/DerivedData`,
         `${this.homeDirPath}/Library/Caches/com.apple.dt.Xcode/Downloads`,
      ];
      dirs.forEach(function(item) {
         puts(`- Deleting: "${item}"`);
         FileSystem.deleteContentsOf(item);
      });
   }
};

// `${this.homeDirPath}/Library/Caches/Firefox/Profiles/*/cache2"`,
//"${this.homeDirPath}/Library/Application Support/Google/Chrome/Default/Application Cache"
// dirs += Dir["${this.homeDirPath}/Library/Caches/AppCode*/caches"]
// dirs += Dir["${this.homeDirPath}/Library/Caches/PyCharm*/caches"]
//"${this.homeDirPath}/Library/Group Containers/K36BKF7T3D.group.com.apple.configurator/Library/Caches/Firmware"
//"${this.homeDirPath}/Library/Group Containers/2E337YPCZY.airmail/Library/Application Support/it.bloop.airmail2/Airmail/General/Icons"
//"${this.homeDirPath}/Music/iTunes/Album Artwork/Cache"
// dirs += Dir["${this.homeDirPath}/Library/Logs/AppCode*"]
// dirs += Dir['/Library/Caches/Avid/*']
// dirs.each { |dirPath|
//    puts "- Deleting: \"${dirPath}\"" if Dir.exist?(dirPath)
//    Dir.deleteIfExists(dirPath)
// }
// puts '- Cleaning up Brew...'
// system('brew cleanup -s 2>/dev/null')
// files = []
// files += Dir["${this.homeDirPath}/Library/Developer/Xcode/iOS Device Logs/*"]
// files.each { |filePath|
//    puts "- Deleting: \"${filePath}\"" if File.exist?(filePath)
//    File.deleteIfExists(filePath)
// }
